diff --git a/README.txt b/README.txt
index acf11fc87da005ec9f27f0855ab509d9e97015c4..3a761425883649ea90090d1c36e4bf5c87077d5e 100644
--- a/README.txt
+++ b/README.txt
@@ -1 +1,2 @@
-See the full documentation on drupal.org: http://drupal.org/documentation/modules/fillpdf
+See the full documentation on drupal.org:
+http://drupal.org/documentation/modules/fillpdf
diff --git a/fillpdf.module b/fillpdf.module
index ae77bd82eb5ac920ab9d742cdf5799f6220759fb..fc5b81a863e4b1c53c26c2658a45dddf8eaebf1d 100644
--- a/fillpdf.module
+++ b/fillpdf.module
@@ -5,6 +5,7 @@
  * Allows mappings of PDFs to site content.
  */
 
+use Drupal\Core\Url;
 use Drupal\Core\Routing\RouteMatchInterface;
 
 /**
@@ -14,15 +15,16 @@ function fillpdf_help($route_name, RouteMatchInterface $route_match) {
   switch ($route_name) {
     case 'help.page.fillpdf':
       $content = t('See the <a href=":documentation">documentation on drupal.org</a> for a full description of and guide to this module.', [
-        ':documentation' => \Drupal\Core\Url::fromUri('https://www.drupal.org/docs/8/modules/fillpdf')
+        ':documentation' => Url::fromUri('https://www.drupal.org/docs/8/modules/fillpdf')
           ->toString(),
       ]);
       return $content;
+
     case 'fillpdf.forms_admin':
       if (\Drupal::moduleHandler()->moduleExists('help')) {
         return t('See the <a href=":link">documentation</a> for an explanation on dowloading these forms to PDF',
           [
-            ':link' => \Drupal\Core\Url::fromUri('https://www.drupal.org/docs/8/modules/fillpdf')
+            ':link' => Url::fromUri('https://www.drupal.org/docs/8/modules/fillpdf')
               ->toString(),
           ]);
       }
diff --git a/modules/fillpdf_legacy/fillpdf_legacy.module b/modules/fillpdf_legacy/fillpdf_legacy.module
index 2281e665b918cd6f9e4235505e7a0fccee69013f..30540d26eff3ec44c4ed27047e763e383e8db01b 100644
--- a/modules/fillpdf_legacy/fillpdf_legacy.module
+++ b/modules/fillpdf_legacy/fillpdf_legacy.module
@@ -1,5 +1,9 @@
 <?php
 
+/**
+ * @file
+ */
+
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\StringTranslation\TranslatableMarkup;
 
diff --git a/modules/fillpdf_legacy/tests/Kernel/LegacyBackendTest.php b/modules/fillpdf_legacy/tests/Kernel/LegacyBackendTest.php
index 2c3748129911f17ec217a0a99634ecc4255a830a..8fbce3a922904eccb62f6a9224c5fb57451662c7 100644
--- a/modules/fillpdf_legacy/tests/Kernel/LegacyBackendTest.php
+++ b/modules/fillpdf_legacy/tests/Kernel/LegacyBackendTest.php
@@ -12,6 +12,9 @@ use Drupal\Tests\fillpdf\Kernel\FillPdfKernelTestBase;
  */
 class LegacyBackendTest extends FillPdfKernelTestBase {
 
+  /**
+   *
+   */
   public function testTestBackend() {
     $backend_manager = $this->container->get('plugin.manager.fillpdf.pdf_backend');
     $test_backend = $backend_manager->createInstance('test');
diff --git a/src/Controller/HandlePdfController.php b/src/Controller/HandlePdfController.php
index eb27ec65897be48880f0de0aa6a1e27a492ac761..44ffc59de82c1bced346aa44a110582fde13ddac 100644
--- a/src/Controller/HandlePdfController.php
+++ b/src/Controller/HandlePdfController.php
@@ -6,15 +6,12 @@ use Drupal\Core\Link;
 use Drupal\Core\Url;
 use Drupal\Core\Controller\ControllerBase;
 use Drupal\Core\StreamWrapper\StreamWrapperInterface;
-use Drupal\file\Entity\File;
 use Drupal\fillpdf\FillPdfContextManagerInterface;
 use Drupal\fillpdf\FillPdfFormInterface;
 use Drupal\fillpdf\FillPdfLinkManipulatorInterface;
 use Drupal\fillpdf\Service\BackendProxyInterface;
 use Drupal\fillpdf\TokenResolverInterface;
-use Drupal\fillpdf\Component\Helper\FillPdfMappingHelper;
 use Drupal\fillpdf\Entity\FillPdfForm;
-use Drupal\fillpdf\FieldMapping\TextFieldMapping;
 use Drupal\fillpdf\Plugin\FillPdfActionPluginManager;
 use Drupal\fillpdf\Plugin\PdfBackendManager;
 use Symfony\Component\DependencyInjection\ContainerInterface;
diff --git a/src/Entity/FillPdfFileContextViewsData.php b/src/Entity/FillPdfFileContextViewsData.php
index 976c586879faeb36fc4e6c3e4ea83e52bcf42a13..526ac3f6d87cc569c08c9d71f7e6adbf287187af 100644
--- a/src/Entity/FillPdfFileContextViewsData.php
+++ b/src/Entity/FillPdfFileContextViewsData.php
@@ -9,17 +9,18 @@ use Drupal\views\EntityViewsDataInterface;
  * Provides Views data for FillPDF file context entities.
  */
 class FillPdfFileContextViewsData extends EntityViewsData implements EntityViewsDataInterface {
+
   /**
    * {@inheritdoc}
    */
   public function getViewsData() {
     $data = parent::getViewsData();
 
-    $data['fillpdf_file_context']['table']['base'] = array(
+    $data['fillpdf_file_context']['table']['base'] = [
       'field' => 'id',
       'title' => $this->t('FillPDF file context'),
       'help' => $this->t('The FillPDF file context ID.'),
-    );
+    ];
 
     return $data;
   }
diff --git a/src/Entity/FillPdfForm.php b/src/Entity/FillPdfForm.php
index 58e7379a6e8601c3470284e990ef978a7eab64c8..f239a94a2b7cb8eeb4559b8518874b47b227ed59 100644
--- a/src/Entity/FillPdfForm.php
+++ b/src/Entity/FillPdfForm.php
@@ -124,7 +124,6 @@ class FillPdfForm extends ContentEntityBase implements FillPdfFormInterface {
       ]);
 
     // @todo: add post_save_redirect field for where to send the browser by default after they generate a PDF
-
     $fields['scheme'] = BaseFieldDefinition::create('list_string')
       ->setLabel('File storage')
       ->setSettings([
diff --git a/src/EntityHelper.php b/src/EntityHelper.php
index 458ddfd68e286b6056a94ba5039b512535339d20..ae333a063a68ffdd05844a9e4064ec1580e55a53 100644
--- a/src/EntityHelper.php
+++ b/src/EntityHelper.php
@@ -6,9 +6,10 @@ namespace Drupal\fillpdf;
  * Class EntityHelper.
  *
  * @package Drupal\fillpdf
- * @deprecated This class and the 'fillpdf.entity_helper' service is deprecated
- *   in FillPDF 8.x-4.7 and will be removed before FillPDF 8.x-5.0.
- *   The getFormFields() method lives within the FillPdfForm entity now.
+ * @deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0. Applies
+ * to this class and the 'fillpdf.entity_helper' service. The getFormFields()
+ * method lives within the FillPdfForm entity now.
+ * @see https://www.drupal.org/project/fillpdf/issues/3046257
  * @see \Drupal\fillpdf\Entity\FillPdfForm::getFormFields()
  */
 class EntityHelper implements EntityHelperInterface {
diff --git a/src/EntityHelperInterface.php b/src/EntityHelperInterface.php
index 9eb0e7c8f9005f6014b917b23fabfb8345ee6114..078d12cf069ceb1de761200fcc41da9627e3213c 100644
--- a/src/EntityHelperInterface.php
+++ b/src/EntityHelperInterface.php
@@ -6,7 +6,8 @@ namespace Drupal\fillpdf;
  * Interface EntityHelperInterface.
  *
  * @package Drupal\fillpdf
- * @deprecated This interface and the 'fillpdf.entity_helper' service is
- *   deprecated in FillPDF 8.x-4.7 and will be removed before FillPDF 8.x-5.0.
+ * @deprecated in FillPDF 8.x-4.7 and is removed from FillPDF 8.x-5.0. Applies
+ * to this interface and the 'fillpdf.entity_helper' service.
+ * @see https://www.drupal.org/project/fillpdf/issues/3046257
  */
 interface EntityHelperInterface {}
diff --git a/src/FieldMapping.php b/src/FieldMapping.php
index 63c6ea21b4c68d90d69e3ef9aa8f69687d8eb10f..056c50fb72d1f13af2461452775fcc96d3078763 100644
--- a/src/FieldMapping.php
+++ b/src/FieldMapping.php
@@ -3,6 +3,8 @@
 namespace Drupal\fillpdf;
 
 /**
+ * Represents a mapping between a PDF field and a merge value.
+ *
  * Represents a mapping between a PDF field and a merge value (a value with
  * which to fill in the field). This is a barebones base class intended to be
  * subclassed and enhanced with additional properties and getter methods.
diff --git a/src/FieldMapping/TextFieldMapping.php b/src/FieldMapping/TextFieldMapping.php
index 6fd4585a423e6f8fcc9568e72c824ca06e7f9aa2..99dffac38f0c39cb2ff90669443495344b2c938c 100644
--- a/src/FieldMapping/TextFieldMapping.php
+++ b/src/FieldMapping/TextFieldMapping.php
@@ -24,7 +24,10 @@ final class TextFieldMapping extends FieldMapping {
   }
 
   /**
+   * Return parent::getData().
+   *
    * @return string
+   *   The return value of parent::getData().
    */
   public function __toString() {
     return parent::getData();
diff --git a/src/FillPdfAccessHelperInterface.php b/src/FillPdfAccessHelperInterface.php
index 8d80126f69337b72041cf2ee435374aadf182578..730b569b62bca518808faf56b3beeda1233cc46a 100644
--- a/src/FillPdfAccessHelperInterface.php
+++ b/src/FillPdfAccessHelperInterface.php
@@ -2,7 +2,6 @@
 
 namespace Drupal\fillpdf;
 
-use Drupal\Core\Access\AccessResultInterface;
 use Drupal\Core\Session\AccountInterface;
 use Drupal\Core\Url;
 
@@ -19,11 +18,13 @@ interface FillPdfAccessHelperInterface {
    * Should ultimately pass control to self::canGeneratePdfFromContext().
    *
    * @param string $url
-   * The root-relative FillPDF URL that would be used to generate the PDF.
-   * e.g. /fillpdf?fid=1&entity_type=node&entity_id=1
+   *   The root-relative FillPDF URL that would be used to generate the PDF.
+   *   e.g. /fillpdf?fid=1&entity_type=node&entity_id=1.
    * @param \Drupal\Core\Session\AccountInterface $account
+   *   The account.
    *
    * @return \Drupal\Core\Access\AccessResultInterface
+   *   The access results.
    *
    * @see \Drupal\fillpdf\FillPdfAccessHelperInterface::canGeneratePdfFromContext()
    */
@@ -41,6 +42,7 @@ interface FillPdfAccessHelperInterface {
    *   The user whose access is being checked.
    *
    * @return \Drupal\Core\Access\AccessResultInterface
+   *   The access results.
    *
    * @see \Drupal\fillpdf\FillPdfAccessHelperInterface::canGeneratePdfFromContext()
    */
@@ -49,7 +51,7 @@ interface FillPdfAccessHelperInterface {
   /**
    * This is the main access checking function of this class.
    *
-   * self::canGeneratePdfFromLinkUrl() should delegate to this one.
+   * Method self::canGeneratePdfFromLinkUrl() should delegate to this one.
    *
    * @param array $context
    *   As returned by FillPdfLinkManipulator's parse functions.
@@ -57,6 +59,7 @@ interface FillPdfAccessHelperInterface {
    *   The user whose access is being checked.
    *
    * @return \Drupal\Core\Access\AccessResultInterface
+   *   The access results.
    *
    * @see \Drupal\fillpdf\FillPdfAccessHelperInterface::canGeneratePdfFromLink()
    */
diff --git a/src/FillPdfFileContextAccessControlHandler.php b/src/FillPdfFileContextAccessControlHandler.php
index 61c7b12be564bade7568ad9232b79635a9bc100a..28e21f01cdc7c6d1dd9baff1bdbb9703539801cc 100644
--- a/src/FillPdfFileContextAccessControlHandler.php
+++ b/src/FillPdfFileContextAccessControlHandler.php
@@ -17,15 +17,24 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  */
 class FillPdfFileContextAccessControlHandler extends EntityAccessControlHandler implements EntityHandlerInterface {
 
-  /** @var \Drupal\fillpdf\FillPdfAccessHelperInterface */
+  /**
+   * @var \Drupal\fillpdf\FillPdfAccessHelperInterface
+   */
   protected $accessHelper;
 
-  /** @var FillPdfLinkManipulatorInterface */
+  /**
+   * @var FillPdfLinkManipulatorInterface
+   */
   protected $linkManipulator;
 
-  /** @var FillPdfContextManagerInterface */
+  /**
+   * @var FillPdfContextManagerInterface
+   */
   protected $contextManager;
 
+  /**
+   *
+   */
   public function __construct(EntityTypeInterface $entity_type, FillPdfAccessHelperInterface $access_helper, FillPdfLinkManipulatorInterface $link_manipulator, FillPdfContextManagerInterface $context_manager) {
     parent::__construct($entity_type);
 
@@ -34,6 +43,9 @@ class FillPdfFileContextAccessControlHandler extends EntityAccessControlHandler
     $this->contextManager = $context_manager;
   }
 
+  /**
+   *
+   */
   public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
     return new static($entity_type, $container->get('fillpdf.access_helper'), $container->get('fillpdf.link_manipulator'), $container->get('fillpdf.context_manager'));
   }
diff --git a/src/FillPdfFormAccessControlHandler.php b/src/FillPdfFormAccessControlHandler.php
index 80e222265c491977885fa811967a027c858efd9e..36d849a2414c0e0d56a8d7124896b30cd783d4ba 100644
--- a/src/FillPdfFormAccessControlHandler.php
+++ b/src/FillPdfFormAccessControlHandler.php
@@ -24,6 +24,7 @@ class FillPdfFormAccessControlHandler extends EntityAccessControlHandler {
       case 'duplicate':
       case 'delete':
         return AccessResult::allowedIfHasPermission($account, 'administer pdfs');
+
       default:
         return AccessResult::neutral();
     }
diff --git a/src/FillPdfFormListBuilder.php b/src/FillPdfFormListBuilder.php
index 363e817046ff2292663c536d0c49bd1422dacd6a..4cbb6c7d42416115e3660826ed677cf64f30532c 100644
--- a/src/FillPdfFormListBuilder.php
+++ b/src/FillPdfFormListBuilder.php
@@ -24,20 +24,20 @@ class FillPdfFormListBuilder extends EntityListBuilder {
   public function getDefaultOperations(EntityInterface $entity) {
 
     $duplicate = [
-        'title' => t('Duplicate'),
-        'weight' => 10,
-        'url' => $this->ensureDestination($entity->toUrl('duplicate-form')),
+      'title' => t('Duplicate'),
+      'weight' => 10,
+      'url' => $this->ensureDestination($entity->toUrl('duplicate-form')),
     ];
     $export = [
-        'title' => t('Export configuration'),
-        'weight' => 20,
-        'url' => $this->ensureDestination($entity->toUrl('export-form')),
+      'title' => t('Export configuration'),
+      'weight' => 20,
+      'url' => $this->ensureDestination($entity->toUrl('export-form')),
     ];
     $import = [
-        'title' => t('Import configuration'),
-        'weight' => 30,
-        'url' => $this->ensureDestination($entity->toUrl('import-form')),
-        ];
+      'title' => t('Import configuration'),
+      'weight' => 30,
+      'url' => $this->ensureDestination($entity->toUrl('import-form')),
+    ];
 
     $operations = parent::getDefaultOperations($entity) + [
       'duplicate' => $duplicate,
diff --git a/src/FillPdfLinkManipulatorInterface.php b/src/FillPdfLinkManipulatorInterface.php
index b17f6704e0c5ecbdb58736324c642a0e646dcd5e..991ec116fb953a3755e3569c2b20f1cf04300a54 100644
--- a/src/FillPdfLinkManipulatorInterface.php
+++ b/src/FillPdfLinkManipulatorInterface.php
@@ -47,8 +47,8 @@ interface FillPdfLinkManipulatorInterface {
    * Parses a Url object.
    *
    * @param \Drupal\Core\Url $link
-   *   The valid URL containing the FillPDF generation metadata.
-   *   e.g. 'http://example.com/fillpdf?entity_ids[]=node:1&entity_ids[]=contact:7'.
+   *   The valid URL containing the FillPDF generation metadata. e.g.
+   *   'http://example.com/fillpdf?entity_ids[]=node:1&entity_ids[]=contact:7'.
    *
    * @return array
    *   An associative array representing the request context and containing the
diff --git a/src/Form/FillPdfAdminFormBase.php b/src/Form/FillPdfAdminFormBase.php
index c7b394cddd081a04d197e6951796cd3ccf93a00e..f99a3f1ec40b0ab3e17b321860fc14ef48ea052a 100644
--- a/src/Form/FillPdfAdminFormBase.php
+++ b/src/Form/FillPdfAdminFormBase.php
@@ -4,14 +4,14 @@ namespace Drupal\fillpdf\Form;
 
 use Drupal\Core\Form\FormBase;
 
-@trigger_error('FillPdfAdminFormBase is deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0. Use \Drupal\Core\Form\FormBase instead. See https://www.drupal.org/project/fillpdf/issues/3044743', E_USER_DEPRECATED);
+@trigger_error('FillPdfAdminFormBase is deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0. Use \Drupal\Core\Form\FormBase instead. See https://www.drupal.org/project/fillpdf/issues/3044743', E_USER_DEPRECATED);
 
 /**
  * Class FillPdfAdminFormBase.
  *
  * @package Drupal\fillpdf\Form
  *
- * @deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0. Use
+ * @deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0. Use
  *   FormBase instead.
  * @see https://www.drupal.org/project/fillpdf/issues/3044743
  * @see \Drupal\Core\Form\FormBase
diff --git a/src/InputHelper.php b/src/InputHelper.php
index cbb9e727ebb910d0a20e125bf37bb84b52ab834b..11c86c899516a7bfce300ccc96d8e0ed1c0b0df6 100644
--- a/src/InputHelper.php
+++ b/src/InputHelper.php
@@ -119,13 +119,13 @@ class InputHelper implements InputHelperInterface {
    * @param \Drupal\file\FileInterface $file
    *   The file object to save.
    *
-   * @deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0.
+   * @deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0.
    *   Use FileInterface::setPermanent() and FileInterface::save() instead.
    * @see https://www.drupal.org/project/fillpdf/issues/3055123
    * @see \Drupal\file\FileInterface
    */
   protected function saveFileUpload(FileInterface $file) {
-    @trigger_error('InputHelper::saveFileUpload() is deprecated in fillpdf:8.x-4.7 and will be removed before fillpdf:8.x-5.0. Use \Drupal\file\FileInterface::setPermanent() and \Drupal\file\FileInterface::save() instead. See https://www.drupal.org/project/fillpdf/issues/3055123.', E_USER_DEPRECATED);
+    @trigger_error('InputHelper::saveFileUpload() is deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0. Use \Drupal\file\FileInterface::setPermanent() and \Drupal\file\FileInterface::save() instead. See https://www.drupal.org/project/fillpdf/issues/3055123.', E_USER_DEPRECATED);
     $file->setPermanent();
     $file->save();
   }
diff --git a/src/Plugin/FillPdfActionPluginBase.php b/src/Plugin/FillPdfActionPluginBase.php
index 9752dd59ecd6551827825a8f1fcfe1153117849f..8ae90d363b876604b23e59c3c47fb217ddde05eb 100644
--- a/src/Plugin/FillPdfActionPluginBase.php
+++ b/src/Plugin/FillPdfActionPluginBase.php
@@ -37,7 +37,7 @@ abstract class FillPdfActionPluginBase extends PluginBase implements FillPdfActi
    * @see \Drupal\Component\Plugin\ConfigurableInterface::getConfiguration()
    */
   public function getConfiguration() {
-    @trigger_error('FillPdfActionPluginInterface::getConfiguration() is deprecated in fillpdf:8.x-4.8 and will be removed before fillpdf:8.x-5.0. Custom FillPdfActionPlugins may extend ConfigurableInterface instead. See https://www.drupal.org/project/fillpdf/issues/3058862.', E_USER_DEPRECATED);
+    @trigger_error('FillPdfActionPluginInterface::getConfiguration() is deprecated in fillpdf:8.x-4.8 and is removed from fillpdf:8.x-5.0. Custom FillPdfActionPlugins may extend ConfigurableInterface instead. See https://www.drupal.org/project/fillpdf/issues/3058862.', E_USER_DEPRECATED);
     return $this->configuration;
   }
 
diff --git a/src/Plugin/PdfBackend/FillPdfServicePdfBackend.php b/src/Plugin/PdfBackend/FillPdfServicePdfBackend.php
index fa3bc8c092e179fbde1f337de97e3d5656ace4f2..b3f6023af577fff802d321f06497fe9c310d9629 100644
--- a/src/Plugin/PdfBackend/FillPdfServicePdfBackend.php
+++ b/src/Plugin/PdfBackend/FillPdfServicePdfBackend.php
@@ -67,9 +67,13 @@ class FillPdfServicePdfBackend extends PdfBackendBase implements FillPdfBackendP
   /**
    * Make an XML-RPC request.
    *
-   * @param $method
+   * @param string $method
+   *   The method to call. Additional arguments are the paramters to the
+   *   xmlrpc() call.
    *
-   * @return \stdClass
+   * @return object
+   *   Object with properties 'error' and 'data' representing the result of the
+   *   request.
    */
   protected function xmlRpcRequest($method /* $args */) {
     $url = $this->configuration['remote_protocol'] . '://' . $this->configuration['remote_endpoint'];
diff --git a/src/Serializer.php b/src/Serializer.php
index ddfcdec634cb0181cfb9cefe2def18552f4cc431..270c4cb388dff7723871f3956adf0025068c6846 100644
--- a/src/Serializer.php
+++ b/src/Serializer.php
@@ -69,8 +69,8 @@ class Serializer implements SerializerInterface {
     foreach ($field_json as $normalized_field) {
       $field = $this->serializer->denormalize($normalized_field, 'Drupal\fillpdf\Entity\FillPdfFormField');
       // @todo: Exported fields are now already keyed by PDF key. For now, we're
-      //   not using the array keys to remain compatible with previous exports,
-      //   but should do so that at some later point.
+      // not using the array keys to remain compatible with previous exports,
+      // but should do so that at some later point.
       $decoded_fields[$field->pdf_key->value] = $field;
     }
 
@@ -136,14 +136,14 @@ class Serializer implements SerializerInterface {
    * @return string[]
    *   Array of unmatched PDF keys.
    *
-   * @deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0.
+   * @deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0.
    *   Field lists are already keyed by pdf_key now, so rekeying them is
    *   unnecessary. Use ::importFormFields instead.
    * @see https://www.drupal.org/project/fillpdf/issues/3055097
    * @see \Drupal\fillpdf\SerializerInterface::importFormFields()
    */
   public function importFormFieldsByKey(array $form_fields, array $existing_fields = []) {
-    @trigger_error('SerializerInterface::importFormFieldsByKey() is deprecated in fillpdf:8.x-4.7 and will be removed before fillpdf:8.x-5.0. Use \Drupal\fillpdf\SerializerInterface::importFormFields() instead. See https://www.drupal.org/project/fillpdf/issues/3055097', E_USER_DEPRECATED);
+    @trigger_error('SerializerInterface::importFormFieldsByKey() is deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0. Use \Drupal\fillpdf\SerializerInterface::importFormFields() instead. See https://www.drupal.org/project/fillpdf/issues/3055097', E_USER_DEPRECATED);
     $keyed_fields = [];
     foreach ($form_fields as $form_field) {
       $keyed_fields[$form_field->pdf_key->value] = $form_field;
diff --git a/src/Service/FillPdfContextManager.php b/src/Service/FillPdfContextManager.php
index 5f8f9778d22688ff66628444a72cb1a1f42748db..35a3f5163fab4682d25ab3f6633e9e1bb92bbe8a 100644
--- a/src/Service/FillPdfContextManager.php
+++ b/src/Service/FillPdfContextManager.php
@@ -5,6 +5,9 @@ namespace Drupal\fillpdf\Service;
 use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\fillpdf\FillPdfContextManagerInterface;
 
+/**
+ *
+ */
 class FillPdfContextManager implements FillPdfContextManagerInterface {
 
   /**
diff --git a/tests/modules/fillpdf_test/src/Plugin/FillPdfBackend/TestFillPdfBackend.php b/tests/modules/fillpdf_test/src/Plugin/FillPdfBackend/TestFillPdfBackend.php
index 7b1be6c901be9053ae4aa7d7d4f7e9144e5fc729..c6e68d920f33437f57ec2bb021484aa777209178 100644
--- a/tests/modules/fillpdf_test/src/Plugin/FillPdfBackend/TestFillPdfBackend.php
+++ b/tests/modules/fillpdf_test/src/Plugin/FillPdfBackend/TestFillPdfBackend.php
@@ -42,7 +42,7 @@ class TestFillPdfBackend implements FillPdfBackendPluginInterface, ContainerFact
    * @param \Drupal\Core\State\StateInterface $state
    *   The state.
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, StateInterface $state) {
+  public function __construct(array $configuration, $plugin_id, array $plugin_definition, StateInterface $state) {
     $this->configuration = $configuration;
     $this->state = $state;
   }
diff --git a/tests/src/Functional/FillPdfFormImportFormTest.php b/tests/src/Functional/FillPdfFormImportFormTest.php
index bff0cc57c1f56fdac3bc80f1aafc59fde736f99b..65510fd10c97c63c31c777aeaa60fa01c9a89d60 100644
--- a/tests/src/Functional/FillPdfFormImportFormTest.php
+++ b/tests/src/Functional/FillPdfFormImportFormTest.php
@@ -54,7 +54,7 @@ class FillPdfFormImportFormTest extends BrowserTestBase {
 
     // Change some configuration.
     // @todo: Even without a destination set, we should always return somewhere
-    //   instead of remaining on the duplicate confirm page.
+    // instead of remaining on the duplicate confirm page.
     $edit = [
       'replacements[0][value]' => 'n|No',
     ];
diff --git a/tests/src/Functional/FillPdfUploadTestBase.php b/tests/src/Functional/FillPdfUploadTestBase.php
index b33fe162f72c58872fa00a16a025383d06f2a121..793b47dd87fb1b9c7770520626995570d32ba8ea 100644
--- a/tests/src/Functional/FillPdfUploadTestBase.php
+++ b/tests/src/Functional/FillPdfUploadTestBase.php
@@ -3,7 +3,6 @@
 namespace Drupal\Tests\fillpdf\Functional;
 
 use Drupal;
-use Drupal\Component\Version\Constraint;
 use Drupal\file\Entity\File;
 use Drupal\fillpdf\Component\Utility\FillPdf;
 use Drupal\Component\Render\FormattableMarkup;
@@ -14,7 +13,7 @@ use Drupal\fillpdf\FillPdfFormInterface;
  *
  * @group fillpdf
  */
-abstract class FillPdfUploadTestBase  extends FillPdfTestBase {
+abstract class FillPdfUploadTestBase extends FillPdfTestBase {
 
   /**
    * Upload a file in the managed file widget.
diff --git a/tests/src/Functional/PdfPopulationTest.php b/tests/src/Functional/PdfPopulationTest.php
index 573df84c2510ac1974a9f80a7e1101625f77a473..8790c7b223cd4ada2aa7009b330d3b998eab096d 100644
--- a/tests/src/Functional/PdfPopulationTest.php
+++ b/tests/src/Functional/PdfPopulationTest.php
@@ -12,7 +12,6 @@ use Drupal\Tests\taxonomy\Traits\TaxonomyTestTrait;
 use Drupal\user\Entity\Role;
 
 // When 8.7.x is fully EOL, this can be removed.
-
 if (!trait_exists('\Drupal\Tests\taxonomy\Traits\TaxonomyTestTrait')) {
   class_alias('\Drupal\Tests\taxonomy\Functional\TaxonomyTestTrait', '\Drupal\Tests\taxonomy\Traits\TaxonomyTestTrait');
 }
@@ -85,10 +84,12 @@ class PdfPopulationTest extends FillPdfTestBase {
     $node = $this->createNode([
       'title' => 'Hello & how are you?',
       'type' => 'article',
-      'body' => [[
-        'value' => "<p>PDF form fields don't accept <em>any</em> HTML.</p>",
-        'format' => 'restricted_html',
-      ]],
+      'body' => [
+        [
+          'value' => "<p>PDF form fields don't accept <em>any</em> HTML.</p>",
+          'format' => 'restricted_html',
+        ],
+      ],
     ]);
 
     // Hit the generation route, check the results from the test backend plugin.
diff --git a/tests/src/Traits/TestFillPdfTrait.php b/tests/src/Traits/TestFillPdfTrait.php
index 187fe9d50484231e3fc1e6e973fd6cb38bf2c109..37aec756cb79b71fe51680d5c6608494710d8220 100644
--- a/tests/src/Traits/TestFillPdfTrait.php
+++ b/tests/src/Traits/TestFillPdfTrait.php
@@ -155,7 +155,7 @@ trait TestFillPdfTrait {
    *   The MIME type.
    *
    * @todo Consider using FileManagedTestBase::createFile() instead.
-   * @see \Drupal\Tests\file\Functional\FileManagedTestBase::createFile().
+   * @see \Drupal\Tests\file\Functional\FileManagedTestBase::createFile()
    */
   protected function getMimeType($content) {
     $finfo = new \finfo(FILEINFO_MIME_TYPE);
diff --git a/tests/src/Unit/FieldMapping/ImageFieldMappingTest.php b/tests/src/Unit/FieldMapping/ImageFieldMappingTest.php
index fcf3772a202033677b5af72804158fb31e4b2bdf..de580ae35e09859881b9da6aa765e964e54d3338 100644
--- a/tests/src/Unit/FieldMapping/ImageFieldMappingTest.php
+++ b/tests/src/Unit/FieldMapping/ImageFieldMappingTest.php
@@ -11,6 +11,9 @@ use Drupal\Tests\UnitTestCase;
  */
 class ImageFieldMappingTest extends UnitTestCase {
 
+  /**
+   *
+   */
   public function test__construct() {
     // Test valid and invalid instantiations.
     $image_field_mapping = new ImageFieldMapping('Dummy image', 'jpg');
@@ -20,6 +23,9 @@ class ImageFieldMappingTest extends UnitTestCase {
     new ImageFieldMapping('Dummy image', 'bmp');
   }
 
+  /**
+   *
+   */
   public function testGetExtension() {
     $image_field_mapping = new ImageFieldMapping('Dummy image', 'jpg');
     self::assertEquals('jpg', $image_field_mapping->getExtension());
diff --git a/tests/src/Unit/FieldMapping/TextFieldMappingTest.php b/tests/src/Unit/FieldMapping/TextFieldMappingTest.php
index 113859c9042f3d692091506f1bc627f2967cba2b..5c3ac1316956123e225bae075349a203959223a5 100644
--- a/tests/src/Unit/FieldMapping/TextFieldMappingTest.php
+++ b/tests/src/Unit/FieldMapping/TextFieldMappingTest.php
@@ -11,12 +11,18 @@ use Drupal\Tests\UnitTestCase;
  */
 class TextFieldMappingTest extends UnitTestCase {
 
+  /**
+   *
+   */
   public function test__construct() {
     // Test valid and invalid instantiations.
     $text_field_mapping = new TextFieldMapping('Dummy text');
     self::assertInstanceOf(TextFieldMapping::class, $text_field_mapping, 'Instantiation works.');
   }
 
+  /**
+   *
+   */
   public function testGetData() {
     $text_field_mapping = new TextFieldMapping('Dummy text');
     self::assertInternalType('string', $text_field_mapping->getData(), 'Data returned as string.');
diff --git a/tests/src/Unit/LinkManipulator/ParseEntityIdsTest.php b/tests/src/Unit/LinkManipulator/ParseEntityIdsTest.php
index 57adc9fea84e1a407c412ebca02bb05134188a35..d6810fce36bf2b794272307f2865b39d09da8595 100644
--- a/tests/src/Unit/LinkManipulator/ParseEntityIdsTest.php
+++ b/tests/src/Unit/LinkManipulator/ParseEntityIdsTest.php
@@ -15,14 +15,14 @@ class ParseEntityIdsTest extends UnitTestCase {
   /**
    * Tests parsing entity IDs from query parameters and back.
    *
-   * @covers ::parseEntityIds
-   * @covers ::prepareEntityIds
-   *
    * @param array $input
    *   Input query parameters.
-   * @param array $input
+   * @param array $expected
    *   Expected output query parameters.
    *
+   * @covers ::parseEntityIds
+   * @covers ::prepareEntityIds
+   *
    * @dataProvider providerTestEntityIds
    */
   public function testEntityIds(array $input, array $expected) {
diff --git a/src/Component/Helper/FillPdfMappingHelper.php b/src/Component/Helper/FillPdfMappingHelper.php
index 611046e6e387f780f1e65318cf36b9153f7599e6..3ba02d397b80ec180ec3c7350fda72d5efbf9e3e 100644
--- a/src/Component/Helper/FillPdfMappingHelper.php
+++ b/src/Component/Helper/FillPdfMappingHelper.php
@@ -57,10 +57,12 @@ class FillPdfMappingHelper {
    * @return string
    *   $value with any matching replacements applied.
    *
    * @deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0.
    */
   public static function transformString($value, array $form_replacements, array $field_replacements) {
-    @trigger_error('transformString is deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0. See https://www.drupal.org/project/fillpdf/issues/3044743', E_USER_DEPRECATED);
+    @trigger_error('transformString is deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0. Deprecated in core. See https://www.drupal.org/project/fillpdf/issues/3044743', E_USER_DEPRECATED);
     // Merge both with field-level replacements taking precedence.
     $replacements = array_merge($form_replacements, $field_replacements);
     return isset($replacements[$value]) ? $replacements[$value] : $value;
@@ -57,10 +57,12 @@ class FillPdfMappingHelper {
    *   $value with any matching replacements applied.
    *
-   * @deprecated in fillpdf:8.x-4.7 and will be removed from fillpdf:8.x-5.0.
+   * @deprecated in fillpdf:8.x-4.7 and is removed from fillpdf:8.x-5.0.
+   * Deprecated in core.
+   * @see https://www.drupal.org/project/fillpdf/issues/3044743
    */
   public static function transformString($value, array $form_replacements, array $field_replacements) {